==> pdal-1.5.0p0.tgz: lib/pdal/cmake/PDALTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pdal_boost" for configuration "Release"
set_property(TARGET pdal_boost APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_boost PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_boost.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_boost )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_boost "${_IMPORT_PREFIX}/lib/libpdal_boost.a" )

# Import target "pdal_arbiter" for configuration "Release"
set_property(TARGET pdal_arbiter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_arbiter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_arbiter.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_arbiter )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_arbiter "${_IMPORT_PREFIX}/lib/libpdal_arbiter.a" )

# Import target "pdal_util" for configuration "Release"
set_property(TARGET pdal_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_util PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_util.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_util "${_IMPORT_PREFIX}/lib/libpdal_util.so.0.0" )

# Import target "pdal_plang" for configuration "Release"
set_property(TARGET pdal_plang APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_plang PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "pdal_base;pdal_util;/usr/local/lib/libpython3.6m.so.0.0"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_plang.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_plang )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_plang "${_IMPORT_PREFIX}/lib/libpdal_plang.so.0.0" )

# Import target "pdal_base" for configuration "Release"
set_property(TARGET pdal_base APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_base PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "pdal_util"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "-lpthread;/usr/local/lib/libgdal.so.29.0;/usr/local/lib/libgeos.so.10.0;/usr/local/lib/libgeotiff.so.2.0;/usr/local/lib/libxml2.so.15.2;/usr/lib/libz.so.5.0;/usr/local/lib/libcurl.so.25.11;/usr/local/lib/libjsoncpp.so.3.0"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_base.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_base )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_base "${_IMPORT_PREFIX}/lib/libpdal_base.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> pdal-1.6p0.tgz: lib/pdal/cmake/PDALTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pdal_boost" for configuration "Release"
set_property(TARGET pdal_boost APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_boost PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_boost.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_boost )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_boost "${_IMPORT_PREFIX}/lib/libpdal_boost.a" )

# Import target "pdal_arbiter" for configuration "Release"
set_property(TARGET pdal_arbiter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_arbiter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_arbiter.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_arbiter )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_arbiter "${_IMPORT_PREFIX}/lib/libpdal_arbiter.a" )

# Import target "pdal_kazhdan" for configuration "Release"
set_property(TARGET pdal_kazhdan APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_kazhdan PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_kazhdan.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_kazhdan )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_kazhdan "${_IMPORT_PREFIX}/lib/libpdal_kazhdan.a" )

# Import target "pdal_util" for configuration "Release"
set_property(TARGET pdal_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_util PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_util.so.0.1"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_util "${_IMPORT_PREFIX}/lib/libpdal_util.so.0.1" )

# Import target "pdal_base" for configuration "Release"
set_property(TARGET pdal_base APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_base PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "pdal_util"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "-lpthread;/usr/local/lib/libgdal.so.30.1;/usr/local/lib/libgeos.so.11.0;/usr/local/lib/libgeotiff.so.2.0;/usr/local/lib/libxml2.so.16.1;/usr/lib/libz.so.5.0;/usr/local/lib/libcurl.so.25.15;/usr/local/lib/libjsoncpp.so.4.0"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libpdal_base.so.1.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_base )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_base "${_IMPORT_PREFIX}/lib/libpdal_base.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
